@@ -1,5 +1,4 @@
-# config_package/__init__.py
-
+from typing import Any, Dict, List, Optional, Type
 from locobuzz_python_configuration.config_builder import ConfigurationBuilder
 from locobuzz_python_configuration.redis_config_builder import RedisConfigurationBuilder
 from locobuzz_python_configuration.sql_config_builder import SQLConfigurationBuilder
@@ -8,12 +7,18 @@ from locobuzz_python_configuration.aws_config_builder import AWSConfigurationBui
 from locobuzz_python_configuration.elastic_config_builder import ElasticSearchConfigurationBuilder
 from locobuzz_python_configuration.kafka_config_builder import KafkaConfigurationBuilder
 
+BuilderClassType = Type[Any]
 
-def create_configuration(file_path=None, config_data=None, required_components=[],
-                         builder_classes=None):
+
+def create_configuration(
+    file_path: Optional[str] = None,
+    config_data: Optional[Dict[str, Any]] = None,
+    required_components: Optional[List[str]] = None,
+    builder_classes: Optional[Dict[str, BuilderClassType]] = None
+) -> Any:
     builder = ConfigurationBuilder()
 
-    default_builders = {
+    default_builders: Dict[str, BuilderClassType] = {
         'sql': SQLConfigurationBuilder,
         'clickhouse': ClickHouseConfigurationBuilder,
         'aws': AWSConfigurationBuilder,
@@ -42,9 +47,9 @@ def create_configuration(file_path=None, config_data=None, required_components=[
 
     try:
         if file_path:
-            builder.load_from_file(file_path, required_components)
+            builder.load_from_file(file_path, required_components or [])
         elif config_data:
-            builder.load_from_dict(config_data, required_components)
+            builder.load_from_dict(config_data, required_components or [])
         else:
             raise ValueError("Either file_path or config_data must be provided")
 
@@ -54,9 +59,9 @@ def create_configuration(file_path=None, config_data=None, required_components=[
         raise e
 
 
-# if __name__ == "__main__":
-#     CONFIG = create_configuration(file_path='appsettings.json', required_components=["redis", "kafka"])
-#     print(CONFIG.__dict__)
-#     SERVICE_NAME = "FACEBOOK_PAGE_INSIGHT_READER_SERVICE"
-#     IS_ASYNC_LOGGER = CONFIG.__dict__.get('_is_async_logger', False)
-
+# Example usage:
+if __name__ == "__main__":
+    CONFIG = create_configuration(file_path='appsettings.json', required_components=["redis", "kafka"])
+    print(CONFIG.__dict__)
+    SERVICE_NAME = "FACEBOOK_PAGE_INSIGHT_READER_SERVICE"
+    IS_ASYNC_LOGGER = CONFIG.__dict__.get('_is_async_logger', False)
